@@ -138,9 +138,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 145 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 142 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+pref("media.ogg.enabled", true);
+//@line 145 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 147 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -156,7 +158,7 @@ pref("gfx.downloadable_fonts.enabled", true);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 163 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 163 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -169,7 +171,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 179 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 179 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -517,9 +519,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 527 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 527 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 529 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 529 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -564,7 +566,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 576 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 576 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -797,7 +799,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 814 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 814 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -816,9 +818,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 834 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 834 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 841 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 841 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1180,15 +1182,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1581 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 1581 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 1998 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 1998 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2199 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2199 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2293 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2293 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2296 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2296 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1456,20 +1458,20 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2566 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2566 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2634 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2634 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2660 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2660 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2680 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2680 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2682 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2682 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2688 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2688 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1493,7 +1495,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2717 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2717 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
